==> qip-catalog-library-0.1.7-sources.jar: org/qubership/integration/platform/catalog/persistence/configs/repository/instructions/ImportInstructionsRepository.java <==
/*
 * Copyright 2024-2025 NetCracker Technology Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.qubership.integration.platform.catalog.persistence.configs.repository.instructions;

import org.qubership.integration.platform.catalog.model.exportimport.instructions.ImportEntityType;
import org.qubership.integration.platform.catalog.model.exportimport.instructions.ImportInstructionAction;
import org.qubership.integration.platform.catalog.persistence.configs.entity.instructions.ImportInstruction;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.stereotype.Repository;

import java.util.Collection;
import java.util.List;

@Repository
public interface ImportInstructionsRepository extends
        JpaRepository<ImportInstruction, String>,
        JpaSpecificationExecutor<ImportInstruction>,
        ImportInstructionsExtendedRepository {
    List<ImportInstruction> findByEntityTypeAndActionIn(ImportEntityType entityType, Collection<ImportInstructionAction> actions);
}

==> qip-catalog-library-2025.1.0.12-sources.jar: org/qubership/integration/platform/catalog/persistence/configs/repository/instructions/ImportInstructionsRepository.java <==
/*
 * Copyright 2024-2025 NetCracker Technology Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.qubership.integration.platform.catalog.persistence.configs.repository.instructions;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.stereotype.Repository;

import org.qubership.integration.platform.catalog.model.exportimport.instructions.ImportEntityType;
import org.qubership.integration.platform.catalog.model.exportimport.instructions.ImportInstructionAction;
import org.qubership.integration.platform.catalog.persistence.configs.entity.instructions.ImportInstruction;

import java.util.Collection;
import java.util.List;

@Repository
public interface ImportInstructionsRepository extends
        JpaRepository<ImportInstruction, String>,
        JpaSpecificationExecutor<ImportInstruction>,
        ImportInstructionsExtendedRepository
{
    List<ImportInstruction> findByEntityTypeAndActionIn(ImportEntityType entityType, Collection<ImportInstructionAction> actions);
}
